@@ -8,7 +8,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(parse_netstat parse_netstat_win);
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 our %SPEC;
 
@@ -229,7 +229,7 @@ Parse::Netstat - Parse the output of "netstat" command
 
 =head1 VERSION
 
-This document describes version 0.07 of Parse::Netstat (from Perl distribution Parse-Netstat), released on 2014-08-16.
+This document describes version 0.08 of Parse::Netstat (from Perl distribution Parse-Netstat), released on 2014-11-09.
 
 =head1 SYNOPSIS
 
@@ -403,11 +403,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
